Cast

Enum Cast 

pub enum Cast<'a, T>
where T: RefFromWasmAbi<Abi = WasmPtr<WasmRefCell<T>>> + LongRefFromWasmAbi<Abi = WasmPtr<WasmRefCell<T>>> + 'a,
{ Ref { anchor: <T as RefFromWasmAbi>::Anchor, }, OwnedRef { js_value: Option<JsValue>, anchor: Option<<T as RefFromWasmAbi>::Anchor>, }, LongRef { anchor: <T as LongRefFromWasmAbi>::Anchor, }, Value { value: Option<T>, }, _Unreachable(Infallible, &'a PhantomData<T>), }
A wrapper for a Rust object that can be either a reference or a value. This wrapper is used to carry a Rust (WASM ABI) reference provided by wasm_bindgen, but at the same time allows creation of a temporary object that can be created by interpreting the source user-supplied data. Cast then provides Cast::as_ref() to obtain the internally held reference and Cast::into_owned() where the latter will consume the value or clone the reference.

Variants



Ref

A borrowed reference to a Rust object obtained from the WASM ABI.

Fields

anchor: <T as RefFromWasmAbi>::Anchor

Anchor keeping the borrowed reference alive.



OwnedRef

A reference that also owns (captures) the source JsValue keeping it alive.

Fields

js_value: Option<JsValue>

The captured source JsValue backing the reference.

anchor: Option<<T as RefFromWasmAbi>::Anchor>

Anchor keeping the borrowed reference alive.



LongRef

A long-lived reference to a Rust object obtained from the WASM ABI.

Fields

anchor: <T as LongRefFromWasmAbi>::Anchor

Anchor keeping the long-lived reference alive.



Value

An owned value, typically created by interpreting user-supplied data.

Fields

value: Option<T>

The owned value.



_Unreachable(Infallible, &'a PhantomData<T>)

Uninhabited variant carrying the lifetime parameter; never constructed.

Implementations

Source

impl<T> Cast<'_, T>
where T: LongRefFromWasmAbi<Abi = WasmPtr<WasmRefCell<T>>> + RefFromWasmAbi<Abi = WasmPtr<WasmRefCell<T>>> + Clone,

pub fn into_owned(self) -> T

Consume the Cast and return the owned value. If the Cast holds a reference, it will be cloned.

pub fn value(value: T) -> Cast<'_, T>

Construct a Cast::Value holding an owned value.