pub struct MultiplexerChannel<T>{
pub id: Id,
pub sender: Sender<T>,
pub receiver: Receiver<T>,
/* private fields */
}Expand description
Receiving channel endpoint for the Multiplexer. MultiplexerChannel<T> holds a Sender and the Receiver channel endpoints.
The Sender is provided for convenience, allowing internal relay within this channel instance.
To process events, simply iterate over MultiplexerChannel::recv() by calling channel.recv().await.
Fields
id: IdUnique id identifying this channel within the parent Multiplexer.
sender: Sender<T>Sender endpoint, provided for convenient internal relay within this channel.
receiver: Receiver<T>Receiver endpoint from which broadcast events are consumed.
Implementations
Sourceimpl<T> MultiplexerChannel<T>
impl<T> MultiplexerChannel<T>
Sourcepub fn close(&self)
pub fn close(&self)
Close the receiving channel. This will unregister the channel from the Multiplexer.
Sourcepub async fn recv(&self) -> Result<T, RecvError>
pub async fn recv(&self) -> Result<T, RecvError>
Receive an event from the channel. This is a blocking async call.
Sourcepub fn try_recv(&self) -> Result<T, TryRecvError>
pub fn try_recv(&self) -> Result<T, TryRecvError>
Receive an event from the channel. This is a non-blocking sync call that
follows Receiver::try_recv semantics.