MenuItemBuilder

Struct MenuItemBuilder 

pub struct MenuItemBuilder {
    pub options: Options,
    pub callback: Option<Callback<CallbackClosure<JsValue>>>,
}
MenuItem Builder

For usage example please refer to Examples

Fields

options: Options

Accumulated NW.js menu item options being configured.

callback: Option<Callback<CallbackClosure<JsValue>>>

Optional callback invoked when the menu item is clicked.

Implementations

Source

impl MenuItemBuilder

pub fn new() -> Self

Creates a new, empty menu item builder.

pub fn set_type(self, t: MenuItemType) -> Self

Type of MenuItem

NWJS Documentation

pub fn label(self, label: &str) -> Self

Label for normal item or checkbox

NWJS Documentation

pub fn icon(self, icon: &str) -> Self

Icon for normal item or checkbox

NWJS Documentation

pub fn tooltip(self, tooltip: &str) -> Self

Tooltip for normal item or checkbox

NWJS Documentation

pub fn callback<F>(self, callback: F) -> Self
where F: FnMut(JsValue) -> Result<(), JsValue> + 'static,

The callback function when item is triggered by mouse click or keyboard shortcut

NWJS Documentation

pub fn enabled(self, enabled: bool) -> Self

Whether the item is enabled or disabled. It’s set to true by default.

NWJS Documentation

pub fn checked(self, checked: bool) -> Self

Whether the checkbox is checked or not. It’s set to false by default.

NWJS Documentation

pub fn submenu(self, submenu: &Menu) -> Self

A submenu

NWJS Documentation

pub fn submenus(self, items: Vec<MenuItem>) -> Self

Create submenu from menu items

NWJS Documentation

pub fn key(self, key: &str) -> Self

The key of the shortcut

NWJS Documentation

pub fn modifiers(self, modifiers: &str) -> Self

The modifiers of the shortcut

NWJS Documentation

pub fn build(self) -> Result<MenuItem>

Builds the configured MenuItem, retaining any click callback in the application so it remains valid.

pub fn finalize( self, ) -> Result<(MenuItem, Option<Callback<CallbackClosure<JsValue>>>)>

Builds the MenuItem and returns it together with its click callback (if any), leaving the caller responsible for retaining the callback.